"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.StreamingConnection = void 0;
var StreamingConnection = /** @class */ (function () {
    function StreamingConnection(url, onMessage, logger) {
        this.url = url;
        this.onMessage = onMessage;
        this.logger = logger;
        this.openConnection();
    }
    StreamingConnection.prototype.openConnection = function () {
        var _this = this;
        this.connection = new EventSource(this.url, { withCredentials: true });
        this.connection.onmessage = function (event) {
            _this.onMessage(event.data);
        };
        this.connection.onerror = function (err) {
            _this.logger.error('StreamingConnection error', err);
        };
        this.connection.onopen = function () {
            _this.logger.debug('StreamingConnection opened');
        };
    };
    StreamingConnection.prototype.isConnected = function () {
        return this.connection.readyState === this.connection.OPEN;
    };
    StreamingConnection.prototype.reopen = function () {
        if (!this.isConnected()) {
            this.close();
            this.openConnection();
        }
    };
    StreamingConnection.prototype.close = function () {
        this.connection.close();
    };
    return StreamingConnection;
}());
exports.StreamingConnection = StreamingConnection;
//# sourceMappingURL=StreamingConnection.js.map